pub enum CreateXErrors {
FailedContractCreation(FailedContractCreation),
FailedContractInitialisation(FailedContractInitialisation),
FailedEtherTransfer(FailedEtherTransfer),
InvalidNonceValue(InvalidNonceValue),
InvalidSalt(InvalidSalt),
}Expand description
Container for all the CreateX custom errors.
Variants
FailedContractCreation(FailedContractCreation)
FailedContractInitialisation(FailedContractInitialisation)
FailedEtherTransfer(FailedEtherTransfer)
InvalidNonceValue(InvalidNonceValue)
InvalidSalt(InvalidSalt)
Implementations
Sourceimpl CreateXErrors
impl CreateXErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl CreateXErrors
impl CreateXErrors
Sourcepub fn failed_contract_creation(emitter: Address) -> Self
pub fn failed_contract_creation(emitter: Address) -> Self
Creates a FailedContractCreation error.
error FailedContractCreation(address)Sourcepub fn failed_contract_initialisation(
emitter: Address,
revert_data: Bytes,
) -> Self
pub fn failed_contract_initialisation( emitter: Address, revert_data: Bytes, ) -> Self
Creates a FailedContractInitialisation error.
error FailedContractInitialisation(address,bytes)Sourcepub fn failed_ether_transfer(emitter: Address, revert_data: Bytes) -> Self
pub fn failed_ether_transfer(emitter: Address, revert_data: Bytes) -> Self
Creates a FailedEtherTransfer error.
error FailedEtherTransfer(address,bytes)Sourcepub fn invalid_nonce_value(emitter: Address) -> Self
pub fn invalid_nonce_value(emitter: Address) -> Self
Creates a InvalidNonceValue error.
error InvalidNonceValue(address)Sourcepub fn invalid_salt(emitter: Address) -> Self
pub fn invalid_salt(emitter: Address) -> Self
Creates a InvalidSalt error.
error InvalidSalt(address)Trait Implementations
Sourceimpl Clone for CreateXErrors
impl Clone for CreateXErrors
Sourcefn clone(&self) -> CreateXErrors
fn clone(&self) -> CreateXErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateXErrors
impl<'de> Deserialize<'de> for CreateXErrors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Serialize for CreateXErrors
impl Serialize for CreateXErrors
Sourceimpl SolInterface for CreateXErrors
impl SolInterface for CreateXErrors
Sourceconst MIN_DATA_LENGTH: usize = 32usize
const MIN_DATA_LENGTH: usize = 32usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreAuto Trait Implementations
impl !Freeze for CreateXErrors
impl RefUnwindSafe for CreateXErrors
impl Send for CreateXErrors
impl Sync for CreateXErrors
impl Unpin for CreateXErrors
impl UnsafeUnpin for CreateXErrors
impl UnwindSafe for CreateXErrors