pub struct CreateXInstance<P, N = Ethereum> {
address: Address,
provider: P,
_network: PhantomData<N>,
}Expand description
A CreateX instance.
Contains type-safe methods for interacting with an on-chain instance of the
CreateX contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Fields
address: Addressprovider: P_network: PhantomData<N>Implementations
Sourceimpl<P: Provider<N>, N: Network> CreateXInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> CreateXInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain CreateX contract instance.
See the wrapper’s documentation for more details.
Sourcepub async fn deploy(__provider: P) -> Result<CreateXInstance<P, N>>
pub async fn deploy(__provider: P) -> Result<CreateXInstance<P, N>>
Deploys this contract using the given provider and constructor arguments, if any.
Returns a new instance of the contract, if the deployment was successful.
For more fine-grained control over the deployment process, use deploy_builder instead.
Sourcepub fn deploy_builder(__provider: P) -> RawCallBuilder<P, N>
pub fn deploy_builder(__provider: P) -> RawCallBuilder<P, N>
Creates a RawCallBuilder for deploying this contract using the given provider
and constructor arguments, if any.
This is a simple wrapper around creating a RawCallBuilder with the data set to
the bytecode concatenated with the constructor’s ABI-encoded arguments.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> CreateXInstance<&P, N>
impl<P: Clone, N> CreateXInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> CreateXInstance<P, N>
pub fn with_cloned_provider(self) -> CreateXInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> CreateXInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> CreateXInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn computeCreate2Address_0(
&self,
salt: FixedBytes<32>,
initCodeHash: FixedBytes<32>,
) -> SolCallBuilder<&P, computeCreate2Address_0Call, N>
pub fn computeCreate2Address_0( &self, salt: FixedBytes<32>, initCodeHash: FixedBytes<32>, ) -> SolCallBuilder<&P, computeCreate2Address_0Call, N>
Creates a new call builder for the [computeCreate2Address_0] function.
Sourcepub fn computeCreate2Address_1(
&self,
salt: FixedBytes<32>,
initCodeHash: FixedBytes<32>,
deployer: Address,
) -> SolCallBuilder<&P, computeCreate2Address_1Call, N>
pub fn computeCreate2Address_1( &self, salt: FixedBytes<32>, initCodeHash: FixedBytes<32>, deployer: Address, ) -> SolCallBuilder<&P, computeCreate2Address_1Call, N>
Creates a new call builder for the [computeCreate2Address_1] function.
Sourcepub fn computeCreate3Address_0(
&self,
salt: FixedBytes<32>,
deployer: Address,
) -> SolCallBuilder<&P, computeCreate3Address_0Call, N>
pub fn computeCreate3Address_0( &self, salt: FixedBytes<32>, deployer: Address, ) -> SolCallBuilder<&P, computeCreate3Address_0Call, N>
Creates a new call builder for the [computeCreate3Address_0] function.
Sourcepub fn computeCreate3Address_1(
&self,
salt: FixedBytes<32>,
) -> SolCallBuilder<&P, computeCreate3Address_1Call, N>
pub fn computeCreate3Address_1( &self, salt: FixedBytes<32>, ) -> SolCallBuilder<&P, computeCreate3Address_1Call, N>
Creates a new call builder for the [computeCreate3Address_1] function.
Sourcepub fn computeCreateAddress_0(
&self,
nonce: U256,
) -> SolCallBuilder<&P, computeCreateAddress_0Call, N>
pub fn computeCreateAddress_0( &self, nonce: U256, ) -> SolCallBuilder<&P, computeCreateAddress_0Call, N>
Creates a new call builder for the [computeCreateAddress_0] function.
Sourcepub fn computeCreateAddress_1(
&self,
deployer: Address,
nonce: U256,
) -> SolCallBuilder<&P, computeCreateAddress_1Call, N>
pub fn computeCreateAddress_1( &self, deployer: Address, nonce: U256, ) -> SolCallBuilder<&P, computeCreateAddress_1Call, N>
Creates a new call builder for the [computeCreateAddress_1] function.
Sourcepub fn deployCreate(
&self,
initCode: Bytes,
) -> SolCallBuilder<&P, deployCreateCall, N>
pub fn deployCreate( &self, initCode: Bytes, ) -> SolCallBuilder<&P, deployCreateCall, N>
Creates a new call builder for the [deployCreate] function.
Sourcepub fn deployCreate2_0(
&self,
salt: FixedBytes<32>,
initCode: Bytes,
) -> SolCallBuilder<&P, deployCreate2_0Call, N>
pub fn deployCreate2_0( &self, salt: FixedBytes<32>, initCode: Bytes, ) -> SolCallBuilder<&P, deployCreate2_0Call, N>
Creates a new call builder for the [deployCreate2_0] function.
Sourcepub fn deployCreate2_1(
&self,
initCode: Bytes,
) -> SolCallBuilder<&P, deployCreate2_1Call, N>
pub fn deployCreate2_1( &self, initCode: Bytes, ) -> SolCallBuilder<&P, deployCreate2_1Call, N>
Creates a new call builder for the [deployCreate2_1] function.
Sourcepub fn deployCreate2AndInit_0(
&self,
salt: FixedBytes<32>,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
refundAddress: Address,
) -> SolCallBuilder<&P, deployCreate2AndInit_0Call, N>
pub fn deployCreate2AndInit_0( &self, salt: FixedBytes<32>, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, refundAddress: Address, ) -> SolCallBuilder<&P, deployCreate2AndInit_0Call, N>
Creates a new call builder for the [deployCreate2AndInit_0] function.
Sourcepub fn deployCreate2AndInit_1(
&self,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
) -> SolCallBuilder<&P, deployCreate2AndInit_1Call, N>
pub fn deployCreate2AndInit_1( &self, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, ) -> SolCallBuilder<&P, deployCreate2AndInit_1Call, N>
Creates a new call builder for the [deployCreate2AndInit_1] function.
Sourcepub fn deployCreate2AndInit_2(
&self,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
refundAddress: Address,
) -> SolCallBuilder<&P, deployCreate2AndInit_2Call, N>
pub fn deployCreate2AndInit_2( &self, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, refundAddress: Address, ) -> SolCallBuilder<&P, deployCreate2AndInit_2Call, N>
Creates a new call builder for the [deployCreate2AndInit_2] function.
Sourcepub fn deployCreate2AndInit_3(
&self,
salt: FixedBytes<32>,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
) -> SolCallBuilder<&P, deployCreate2AndInit_3Call, N>
pub fn deployCreate2AndInit_3( &self, salt: FixedBytes<32>, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, ) -> SolCallBuilder<&P, deployCreate2AndInit_3Call, N>
Creates a new call builder for the [deployCreate2AndInit_3] function.
Sourcepub fn deployCreate2Clone_0(
&self,
salt: FixedBytes<32>,
implementation: Address,
data: Bytes,
) -> SolCallBuilder<&P, deployCreate2Clone_0Call, N>
pub fn deployCreate2Clone_0( &self, salt: FixedBytes<32>, implementation: Address, data: Bytes, ) -> SolCallBuilder<&P, deployCreate2Clone_0Call, N>
Creates a new call builder for the [deployCreate2Clone_0] function.
Sourcepub fn deployCreate2Clone_1(
&self,
implementation: Address,
data: Bytes,
) -> SolCallBuilder<&P, deployCreate2Clone_1Call, N>
pub fn deployCreate2Clone_1( &self, implementation: Address, data: Bytes, ) -> SolCallBuilder<&P, deployCreate2Clone_1Call, N>
Creates a new call builder for the [deployCreate2Clone_1] function.
Sourcepub fn deployCreate3_0(
&self,
initCode: Bytes,
) -> SolCallBuilder<&P, deployCreate3_0Call, N>
pub fn deployCreate3_0( &self, initCode: Bytes, ) -> SolCallBuilder<&P, deployCreate3_0Call, N>
Creates a new call builder for the [deployCreate3_0] function.
Sourcepub fn deployCreate3_1(
&self,
salt: FixedBytes<32>,
initCode: Bytes,
) -> SolCallBuilder<&P, deployCreate3_1Call, N>
pub fn deployCreate3_1( &self, salt: FixedBytes<32>, initCode: Bytes, ) -> SolCallBuilder<&P, deployCreate3_1Call, N>
Creates a new call builder for the [deployCreate3_1] function.
Sourcepub fn deployCreate3AndInit_0(
&self,
salt: FixedBytes<32>,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
) -> SolCallBuilder<&P, deployCreate3AndInit_0Call, N>
pub fn deployCreate3AndInit_0( &self, salt: FixedBytes<32>, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, ) -> SolCallBuilder<&P, deployCreate3AndInit_0Call, N>
Creates a new call builder for the [deployCreate3AndInit_0] function.
Sourcepub fn deployCreate3AndInit_1(
&self,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
) -> SolCallBuilder<&P, deployCreate3AndInit_1Call, N>
pub fn deployCreate3AndInit_1( &self, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, ) -> SolCallBuilder<&P, deployCreate3AndInit_1Call, N>
Creates a new call builder for the [deployCreate3AndInit_1] function.
Sourcepub fn deployCreate3AndInit_2(
&self,
salt: FixedBytes<32>,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
refundAddress: Address,
) -> SolCallBuilder<&P, deployCreate3AndInit_2Call, N>
pub fn deployCreate3AndInit_2( &self, salt: FixedBytes<32>, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, refundAddress: Address, ) -> SolCallBuilder<&P, deployCreate3AndInit_2Call, N>
Creates a new call builder for the [deployCreate3AndInit_2] function.
Sourcepub fn deployCreate3AndInit_3(
&self,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
refundAddress: Address,
) -> SolCallBuilder<&P, deployCreate3AndInit_3Call, N>
pub fn deployCreate3AndInit_3( &self, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, refundAddress: Address, ) -> SolCallBuilder<&P, deployCreate3AndInit_3Call, N>
Creates a new call builder for the [deployCreate3AndInit_3] function.
Sourcepub fn deployCreateAndInit_0(
&self,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
) -> SolCallBuilder<&P, deployCreateAndInit_0Call, N>
pub fn deployCreateAndInit_0( &self, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, ) -> SolCallBuilder<&P, deployCreateAndInit_0Call, N>
Creates a new call builder for the [deployCreateAndInit_0] function.
Sourcepub fn deployCreateAndInit_1(
&self,
initCode: Bytes,
data: Bytes,
values: <Values as SolType>::RustType,
refundAddress: Address,
) -> SolCallBuilder<&P, deployCreateAndInit_1Call, N>
pub fn deployCreateAndInit_1( &self, initCode: Bytes, data: Bytes, values: <Values as SolType>::RustType, refundAddress: Address, ) -> SolCallBuilder<&P, deployCreateAndInit_1Call, N>
Creates a new call builder for the [deployCreateAndInit_1] function.
Sourcepub fn deployCreateClone(
&self,
implementation: Address,
data: Bytes,
) -> SolCallBuilder<&P, deployCreateCloneCall, N>
pub fn deployCreateClone( &self, implementation: Address, data: Bytes, ) -> SolCallBuilder<&P, deployCreateCloneCall, N>
Creates a new call builder for the [deployCreateClone] function.
Sourceimpl<P: Provider<N>, N: Network> CreateXInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> CreateXInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn ContractCreation_0_filter(&self) -> Event<&P, ContractCreation_0, N>
pub fn ContractCreation_0_filter(&self) -> Event<&P, ContractCreation_0, N>
Creates a new event filter for the ContractCreation_0 event.
Sourcepub fn ContractCreation_1_filter(&self) -> Event<&P, ContractCreation_1, N>
pub fn ContractCreation_1_filter(&self) -> Event<&P, ContractCreation_1, N>
Creates a new event filter for the ContractCreation_1 event.
Sourcepub fn Create3ProxyContractCreation_filter(
&self,
) -> Event<&P, Create3ProxyContractCreation, N>
pub fn Create3ProxyContractCreation_filter( &self, ) -> Event<&P, Create3ProxyContractCreation, N>
Creates a new event filter for the Create3ProxyContractCreation event.